@@ -40,6 +40,7 @@ import uuid
 import os
 import decorator
 
+from errormator_client import __version__, __protocol_version__ 
 from errormator_client.ext_json import json
 from errormator_client.utils import asbool, aslist
 from errormator_client.timing import local_timing, get_local_storage
@@ -64,8 +65,8 @@ log = logging.getLogger(__name__)
 
 
 class Client(object):
-    __version__ = '0.5.6'
-    __protocol_version__ = '0.3.5'
+    __version__ = __version__
+    __protocol_version__ = __protocol_version__ 
 
     def __init__(self, config=None, register_timing=True):
         """
@@ -156,14 +157,14 @@ class Client(object):
                             seconds=self.config['buffer_flush_interval'])
         # register logging
         import errormator_client.logger
-        if self.config['logging']:
+        if self.config['logging'] and self.config['enabled']:
             self.log_handler = errormator_client.logger.register_logging()
             level = LEVELS.get(config.get('errormator.logging.level',
                                       'WARNING').lower(), logging.WARNING)
             self.log_handler.setLevel(level)
 
         # register slow call metrics
-        if self.config['slow_requests']:
+        if self.config['slow_requests'] and self.config['enabled']:
             self.config['timing'] = config.get('errormator.timing', {})
             for k, v in config.items():
                 if k.startswith('errormator.timing'):
@@ -386,7 +387,10 @@ class Client(object):
                 self.request_stats[req_time] = {'main': 0, 'sql': 0,
                                                 'nosql': 0, 'remote': 0,
                                                 'tmpl': 0, 'unknown': 0,
-                                                'requests': 0}
+                                                'requests': 0, 'sql_calls':0,
+                                                'nosql_calls':0,
+                                                'remote_calls':0,
+                                                'tmpl_calls':0}
             self.request_stats[req_time]['requests'] += 1
             for k, v in stats.iteritems():
                 self.request_stats[req_time][k] += v
